/**
 * top5tour.java
 * The top 5 tour applet is a simple applet which loads documents into
 * a named window.  I've used frames to do the work of naming the window
 * into which the documents gets loaded.
 * Use a tag like FRAME="myhtml" NAME="TARG"  (I'm not putting the full
 * tag since I'm not sure of what it will do to javadoc
 *
 * @author Paul B. Monday
 */

import java.applet.*;
import java.io.*;
import java.net.*;
import java.awt.*;

public class AutoDemo extends Applet implements Runnable
{
        private final int DEFAULT_MAXLINKS=20;
        private final int DEFAULT_DELAY=10000;
        private String links[] = new String[DEFAULT_MAXLINKS];
        private int delay;
        private Thread runner;
        private String loop;
        private String finishLink;

        public void init()
        {
                String s;
                int i=0;
                /*
                 * This is a very cool thing I found in Core Java
                 * which allows a 'dynamic' amount of PARAMs in
                 * the html document
                 *
                 * Converting the links[] to a vector would eliminate the
                 * need for a MAXLINKS, unfortunately, I don't know vectors
                 * yet...can't be too hard though
                 */
                while( ((s = getParameter("link_" + i))!= null) && (i<DEFAULT_MAXLINKS)){
                        links[i] = new String(s);
                        i++;
                }

                /*
                 * Get the delay parameter
                 */
                delay = Integer.parseInt(getParameter("delay"));

                /*
                 * The loop value says if we should just loop on the
                 * links we have, or if we should go to the finishLink
                 * after we're done with the loop
                 */
                loop = getParameter("loop");
                finishLink = getParameter("finishLink");

                /*
                 * Add control buttons
                 */
                add(new Button("Pause"));
                add(new Button("Continue"));
                add(new Button("Exit"));
                setBackground(Color.black);
        }

        public boolean action(Event evt, Object arg)
        {
                if(arg.equals("Pause")){
                        if(runner!=null){
                                if(runner.isAlive())
                                        runner.suspend();
                        }
                        return true;
                }
                else if(arg.equals("Continue")) {
                        if(runner==null){
                                runner.start();
                        }
                        else{
                                runner.resume();
                        }                        
                        return true;
                }
                else if(arg.equals("Exit")) {
                        if(runner!=null)
                                if(runner.isAlive())
                                        runner.stop();
                        try{
                               URL u = new URL(finishLink);
                               AppletContext context = getAppletContext();
                               context.showDocument(u, "_parent");
                        }
                        catch(Exception e){
                               System.err.println("Error in Exit URL: " + e);
                        }
                        return true;
                }
                return false;
        }

        public void run(){
                int i;
                boolean continuous=false, loopedOnce=false;
                AppletContext context = getAppletContext();
                URL u;

                if(loop.toLowerCase().equals("yes")){
                    continuous=true;
                }
                while(continuous || !loopedOnce){
                    for(i=0 ; i<links.length ; i++){
                            try{
                                    if(links[i]!=null){
                                            u = new URL(links[i]);
                                            context.showDocument(u, "dock");
                                            runner.sleep(delay);
                                    }
                            }
                            catch(Exception e){
                                    System.err.println("Error " + e);
                            }
                    }
                    loopedOnce=true;
                }
                try{
                    u = new URL(finishLink);
                    context.showDocument(u, "_parent");
                }
                catch(Exception e){
                    System.err.println("Error " + e);
                }
        }

        public void start(){
                if(runner == null){
                        runner = new Thread(this);
                        runner.start();
                }
        }

        public void stop(){
                if(runner != null ){
                        runner.stop();
                        runner = null;
                }
        }
}
